@@ -13,7 +13,7 @@ import filecmp
 
 import xlwt3
 
-def from_tests_dir(filename):
+def from_tst_dir(filename):
     return os.path.join(os.path.dirname(os.path.abspath(__file__)), filename)
 
 class TestMini(unittest.TestCase):
@@ -22,8 +22,8 @@ class TestMini(unittest.TestCase):
         sheet = book.add_sheet('xlwt was here')
         book.save('mini.xls')
 
-        self.assertTrue(filecmp.cmp(from_tests_dir('mini.xls'),
-                                    from_tests_dir('output-0.7.2/mini.xls'),
+        self.assertTrue(filecmp.cmp(from_tst_dir('mini.xls'),
+                                    from_tst_dir(os.path.join('output-0.7.2', 'mini.xls')),
                                     shallow=False))
 
 if __name__=='__main__':
