@@ -14,7 +14,7 @@ from datetime import datetime
 
 import xlwt3 as xlwt
 
-def from_tests_dir(filename):
+def from_tst_dir(filename):
     return os.path.join(os.path.dirname(os.path.abspath(__file__)), filename)
 
 class TestSimple(unittest.TestCase):
@@ -43,8 +43,8 @@ class TestSimple(unittest.TestCase):
 
     def test_create_simple_xls(self):
         self.create_simple_xls()
-        self.assertTrue(filecmp.cmp(from_tests_dir('simple.xls'),
-                                    from_tests_dir('output-0.7.2/simple.xls'),
+        self.assertTrue(filecmp.cmp(from_tst_dir('simple.xls'),
+                                    from_tst_dir(os.path.join('output-0.7.2', 'simple.xls')),
                                     shallow=False))
 
 if __name__=='__main__':
